package ansifmt

  1. Overview
  2. Docs

Module Ansifmt.FormattingSource

Sourcemodule Token_type : sig ... end
Sourcemodule Stylizer : sig ... end
Sourcemodule Token : sig ... end

Token is the formatter token data type.

Sourcemodule type TOKENIZABLE = sig ... end

TOKENIZABLE is the interface for languages which terms can be transformed into a stream of formatter tokens.

Sourcemodule Util : sig ... end