package ansifmt

  1. Overview
  2. Docs

Module type Formatting.TOKENIZABLESource

TOKENIZABLE is the interface for languages which terms can be transformed into a stream of formatter tokens.

type t

t encodes the language.

val tokenize : t -> Token.t list

tokenize term transforms term into a stream of formatter tokens.